# PolyRat: Polynomial and Rational Function Library

[![PyPI version](https://badge.fury.io/py/polyrat.svg)](https://badge.fury.io/py/polyrat)
[![Build Status](https://travis-ci.org/jeffrey-hokanson/polyrat.svg?branch=master)](https://travis-ci.org/jeffrey-hokanson/polyrat)
[![Coverage Status](https://coveralls.io/repos/github/jeffrey-hokanson/polyrat/badge.svg?branch=master)](https://coveralls.io/github/jeffrey-hokanson/polyrat?branch=master)



## Installation

    > pip install --upgrade polyrat


## Reproducibility

This repository contains the code to reproduce the figures in the associated papers

* [Multivariate Rational Approximation Using a Stabilized Sanathanan-Koerner Iteration](https://arxiv.org/abs/2009.10803)
  in [Reproducibility/Stabilized_SK](Reproducibility/Stabilized_SK)


## Related Projects

* [baryrat](https://github.com/c-f-h/baryrat): Pure python implementation of the AAA algorithm

